window.Gleam.initSearch([{"doc":"glisten","title":"glisten","content":"# glisten\n\n[![Package Version](https://img.shields.io/hexpm/v/glisten)](https://hex.pm/packages/glisten)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/glisten/)\n\nA Gleam TCP server library.  Built on top of `gleam_otp`, it provides a\nsupervisor over a pool of socket acceptors.  Each acceptor will block on `accept`\nuntil a connection is opened.  The acceptor will then spawn a handler process\nand then block again on `accept`.\n\nHere is a simple example that will echo received messages:\n\n```gleam\nimport gleam/bytes_builder\nimport gleam/erlang/process\nimport gleam/option.{None}\nimport gleam/otp/actor\nimport glisten.{Packet}\n\npub fn main() {\n  let assert Ok(_) =\n    glisten.handler(fn() { #(Nil, None) }, fn(msg, state, conn) {\n      let assert Packet(msg) = msg\n      let assert Ok(_) = glisten.send(conn, bytes_builder.from_bit_array(msg))\n      actor.continue(state)\n    })\n    |&gt; glisten.serve(3000)\n\n  process.sleep_forever()\n}\n```\n\nSSL is also handled using the `glisten.{serve_ssl}` method.  This requires a\ncertificate and key file path.  The rest of the handler flow remains unchanged.\n\n`glisten` doesn&#39;t provide a public API for connected clients.  In order to hook\ninto the socket lifecyle, you can establish some functions which are called\nfor the opening and closing of the socket.  An example is provided below.\n\nTo serve over SSL:\n\n```gleam\n// ...\nimport glisten/ssl\n\npub fn main() {\n  let assert Ok(_) =\n    glisten.handler(\n      // omitted\n    )\n    |&gt; glisten.serve_ssl(\n      // Passing labeled arguments for clarity\n      port: 8080,\n      certfile: &quot;/path/to/server.crt&quot;,\n      keyfile: &quot;/path/to/server.key&quot;,\n    )\n  process.sleep_forever()\n}\n```\n\nBut you can also drop down to the lower level listen/accept flow if you&#39;d prefer\nto manage connections yourself, or only handle a small number at a time.\n\n```gleam\nimport gleam/io\nimport gleam/result\nimport glisten/socket/options.{ActiveMode, Passive}\nimport glisten/tcp\n\npub fn main() {\n  use listener &lt;- result.then(tcp.listen(8000, [ActiveMode(Passive)]))\n  use socket &lt;- result.then(tcp.accept(listener))\n  use msg &lt;- result.then(tcp.receive(socket, 0))\n  io.debug(#(&quot;got a msg&quot;, msg))\n\n  Ok(Nil)\n}\n```\n\nSee [mist](https://github.com/rawhat/mist) for HTTP support built on top of this library.\n","url":"index.html"},{"doc":"glisten/socket","title":"ListenSocket","content":"pub opaque type ListenSocket\n\n\nSynonyms:\nglisten/socket.ListenSocket\nglisten/socket ListenSocket","url":"glisten/socket.html#ListenSocket"},{"doc":"glisten/socket","title":"Socket","content":"pub opaque type Socket\n\n\nSynonyms:\nglisten/socket.Socket\nglisten/socket Socket","url":"glisten/socket.html#Socket"},{"doc":"glisten/socket","title":"SocketReason","content":"pub type SocketReason {\n  Closed\n  Timeout\n  Badarg\n  Terminated\n  Eaddrinuse\n  Eaddrnotavail\n  Eafnosupport\n  Ealready\n  Econnaborted\n  Econnrefused\n  Econnreset\n  Edestaddrreq\n  Ehostdown\n  Ehostunreach\n  Einprogress\n  Eisconn\n  Emsgsize\n  Enetdown\n  Enetunreach\n  Enopkg\n  Enoprotoopt\n  Enotconn\n  Enotty\n  Enotsock\n  Eproto\n  Eprotonosupport\n  Eprototype\n  Esocktnosupport\n  Etimedout\n  Ewouldblock\n  Exbadport\n  Exbadseq\n  Eacces\n  Eagain\n  Ebadf\n  Ebadmsg\n  Ebusy\n  Edeadlk\n  Edeadlock\n  Edquot\n  Eexist\n  Efault\n  Efbig\n  Eftype\n  Eintr\n  Einval\n  Eio\n  Eisdir\n  Eloop\n  Emfile\n  Emlink\n  Emultihop\n  Enametoolong\n  Enfile\n  Enobufs\n  Enodev\n  Enolck\n  Enolink\n  Enoent\n  Enomem\n  Enospc\n  Enosr\n  Enostr\n  Enosys\n  Enotblk\n  Enotdir\n  Enotsup\n  Enxio\n  Eopnotsupp\n  Eoverflow\n  Eperm\n  Epipe\n  Erange\n  Erofs\n  Espipe\n  Esrch\n  Estale\n  Etxtbsy\n  Exdev\n}\n\nClosed\n\n\nTimeout\n\n\nBadarg\n\n\nTerminated\n\n\nEaddrinuse\n\n\nEaddrnotavail\n\n\nEafnosupport\n\n\nEalready\n\n\nEconnaborted\n\n\nEconnrefused\n\n\nEconnreset\n\n\nEdestaddrreq\n\n\nEhostdown\n\n\nEhostunreach\n\n\nEinprogress\n\n\nEisconn\n\n\nEmsgsize\n\n\nEnetdown\n\n\nEnetunreach\n\n\nEnopkg\n\n\nEnoprotoopt\n\n\nEnotconn\n\n\nEnotty\n\n\nEnotsock\n\n\nEproto\n\n\nEprotonosupport\n\n\nEprototype\n\n\nEsocktnosupport\n\n\nEtimedout\n\n\nEwouldblock\n\n\nExbadport\n\n\nExbadseq\n\n\nEacces\n\n\nEagain\n\n\nEbadf\n\n\nEbadmsg\n\n\nEbusy\n\n\nEdeadlk\n\n\nEdeadlock\n\n\nEdquot\n\n\nEexist\n\n\nEfault\n\n\nEfbig\n\n\nEftype\n\n\nEintr\n\n\nEinval\n\n\nEio\n\n\nEisdir\n\n\nEloop\n\n\nEmfile\n\n\nEmlink\n\n\nEmultihop\n\n\nEnametoolong\n\n\nEnfile\n\n\nEnobufs\n\n\nEnodev\n\n\nEnolck\n\n\nEnolink\n\n\nEnoent\n\n\nEnomem\n\n\nEnospc\n\n\nEnosr\n\n\nEnostr\n\n\nEnosys\n\n\nEnotblk\n\n\nEnotdir\n\n\nEnotsup\n\n\nEnxio\n\n\nEopnotsupp\n\n\nEoverflow\n\n\nEperm\n\n\nEpipe\n\n\nErange\n\n\nErofs\n\n\nEspipe\n\n\nEsrch\n\n\nEstale\n\n\nEtxtbsy\n\n\nExdev\n\n\nSynonyms:\nglisten/socket.SocketReason\nglisten/socket SocketReason","url":"glisten/socket.html#SocketReason"},{"doc":"glisten/socket","title":"glisten/socket","content":"","url":"glisten/socket.html"},{"doc":"glisten/socket/options","title":"ActiveState","content":"pub type ActiveState {\n  Once\n  Passive\n  Count(Int)\n  Active\n}\n Mapping to the {active, _} option\nOnce\n\n\nPassive\n\n\nCount(Int)\n\n\nActive\n\n\nSynonyms:\nglisten/socket/options.ActiveState\nglisten/socket/options ActiveState","url":"glisten/socket/options.html#ActiveState"},{"doc":"glisten/socket/options","title":"SocketMode","content":"pub type SocketMode {\n  Binary\n}\n Mode for the socket.  Currently `list` is not supported\nBinary\n\n\nSynonyms:\nglisten/socket/options.SocketMode\nglisten/socket/options SocketMode","url":"glisten/socket/options.html#SocketMode"},{"doc":"glisten/socket/options","title":"TcpOption","content":"pub type TcpOption {\n  Backlog(Int)\n  Nodelay(Bool)\n  Linger(#(Bool, Int))\n  SendTimeout(Int)\n  SendTimeoutClose(Bool)\n  Reuseaddr(Bool)\n  ActiveMode(ActiveState)\n  Mode(SocketMode)\n  Certfile(String)\n  Keyfile(String)\n  AlpnPreferredProtocols(List(String))\n  Inet6\n}\n Options for the TCP socket\nBacklog(Int)\n\n\nNodelay(Bool)\n\n\nLinger(#(Bool, Int))\n\n\nSendTimeout(Int)\n\n\nSendTimeoutClose(Bool)\n\n\nReuseaddr(Bool)\n\n\nActiveMode(ActiveState)\n\n\nMode(SocketMode)\n\n\nCertfile(String)\n\n\nKeyfile(String)\n\n\nAlpnPreferredProtocols(List(String))\n\n\nInet6\n\n\nSynonyms:\nglisten/socket/options.TcpOption\nglisten/socket/options TcpOption","url":"glisten/socket/options.html#TcpOption"},{"doc":"glisten/socket/options","title":"default_options","content":"pub const default_options: List(TcpOption) = [\n  Backlog(1024),\n  Nodelay(True),\n  SendTimeout(30_000),\n  SendTimeoutClose(True),\n  Reuseaddr(True),\n  Mode(Binary),\n  ActiveMode(Passive),\n]\n\nSynonyms:\nglisten/socket/options.default_options\nglisten/socket/options default_options","url":"glisten/socket/options.html#default_options"},{"doc":"glisten/socket/options","title":"merge_with_defaults","content":"pub fn merge_with_defaults(\n  options: List(TcpOption),\n) -&gt; List(TcpOption)\n\nSynonyms:\nglisten/socket/options.merge_with_defaults\nglisten/socket/options merge_with_defaults","url":"glisten/socket/options.html#merge_with_defaults"},{"doc":"glisten/socket/options","title":"to_dict","content":"pub fn to_dict(options: List(TcpOption)) -&gt; Dict(Atom, Dynamic)\n\nSynonyms:\nglisten/socket/options.to_dict\nglisten/socket/options to_dict","url":"glisten/socket/options.html#to_dict"},{"doc":"glisten/socket/options","title":"glisten/socket/options","content":"","url":"glisten/socket/options.html"},{"doc":"glisten/ssl","title":"accept","content":"pub fn accept(\n  socket: ListenSocket,\n) -&gt; Result(Socket, SocketReason)\n\nSynonyms:\nglisten/ssl.accept\nglisten/ssl accept","url":"glisten/ssl.html#accept"},{"doc":"glisten/ssl","title":"accept_timeout","content":"pub fn accept_timeout(\n  socket: ListenSocket,\n  timeout: Int,\n) -&gt; Result(Socket, SocketReason)\n\nSynonyms:\nglisten/ssl.accept_timeout\nglisten/ssl accept_timeout","url":"glisten/ssl.html#accept_timeout"},{"doc":"glisten/ssl","title":"close","content":"pub fn close(socket: Socket) -&gt; Result(Nil, SocketReason)\n\nSynonyms:\nglisten/ssl.close\nglisten/ssl close","url":"glisten/ssl.html#close"},{"doc":"glisten/ssl","title":"controlling_process","content":"pub fn controlling_process(\n  socket: Socket,\n  pid: Pid,\n) -&gt; Result(Nil, Atom)\n\nSynonyms:\nglisten/ssl.controlling_process\nglisten/ssl controlling_process","url":"glisten/ssl.html#controlling_process"},{"doc":"glisten/ssl","title":"do_shutdown","content":"pub fn do_shutdown(\n  socket: Socket,\n  write: Atom,\n) -&gt; Result(Nil, SocketReason)\n\nSynonyms:\nglisten/ssl.do_shutdown\nglisten/ssl do_shutdown","url":"glisten/ssl.html#do_shutdown"},{"doc":"glisten/ssl","title":"handshake","content":"pub fn handshake(socket: Socket) -&gt; Result(Socket, Nil)\n\nSynonyms:\nglisten/ssl.handshake\nglisten/ssl handshake","url":"glisten/ssl.html#handshake"},{"doc":"glisten/ssl","title":"listen","content":"pub fn listen(\n  port: Int,\n  options: List(TcpOption),\n) -&gt; Result(ListenSocket, SocketReason)\n Start listening over SSL on a port with the given options\nSynonyms:\nglisten/ssl.listen\nglisten/ssl listen","url":"glisten/ssl.html#listen"},{"doc":"glisten/ssl","title":"negotiated_protocol","content":"pub fn negotiated_protocol(\n  socket: Socket,\n) -&gt; Result(String, String)\n\nSynonyms:\nglisten/ssl.negotiated_protocol\nglisten/ssl negotiated_protocol","url":"glisten/ssl.html#negotiated_protocol"},{"doc":"glisten/ssl","title":"peername","content":"pub fn peername(\n  socket: Socket,\n) -&gt; Result(#(#(Int, Int, Int, Int), Int), Nil)\n\nSynonyms:\nglisten/ssl.peername\nglisten/ssl peername","url":"glisten/ssl.html#peername"},{"doc":"glisten/ssl","title":"receive","content":"pub fn receive(\n  socket: Socket,\n  length: Int,\n) -&gt; Result(BitArray, SocketReason)\n\nSynonyms:\nglisten/ssl.receive\nglisten/ssl receive","url":"glisten/ssl.html#receive"},{"doc":"glisten/ssl","title":"receive_timeout","content":"pub fn receive_timeout(\n  socket: Socket,\n  length: Int,\n  timeout: Int,\n) -&gt; Result(BitArray, SocketReason)\n\nSynonyms:\nglisten/ssl.receive_timeout\nglisten/ssl receive_timeout","url":"glisten/ssl.html#receive_timeout"},{"doc":"glisten/ssl","title":"send","content":"pub fn send(\n  socket: Socket,\n  packet: BytesBuilder,\n) -&gt; Result(Nil, SocketReason)\n\nSynonyms:\nglisten/ssl.send\nglisten/ssl send","url":"glisten/ssl.html#send"},{"doc":"glisten/ssl","title":"set_opts","content":"pub fn set_opts(\n  socket: Socket,\n  opts: List(TcpOption),\n) -&gt; Result(Nil, Nil)\n Update the optons for a socket (mutates the socket)\nSynonyms:\nglisten/ssl.set_opts\nglisten/ssl set_opts","url":"glisten/ssl.html#set_opts"},{"doc":"glisten/ssl","title":"shutdown","content":"pub fn shutdown(socket: Socket) -&gt; Result(Nil, SocketReason)\n\nSynonyms:\nglisten/ssl.shutdown\nglisten/ssl shutdown","url":"glisten/ssl.html#shutdown"},{"doc":"glisten/ssl","title":"start","content":"pub fn start() -&gt; Result(Nil, Dynamic)\n\nSynonyms:\nglisten/ssl.start\nglisten/ssl start","url":"glisten/ssl.html#start"},{"doc":"glisten/ssl","title":"glisten/ssl","content":"","url":"glisten/ssl.html"},{"doc":"glisten/tcp","title":"accept","content":"pub fn accept(\n  socket: ListenSocket,\n) -&gt; Result(Socket, SocketReason)\n\nSynonyms:\nglisten/tcp.accept\nglisten/tcp accept","url":"glisten/tcp.html#accept"},{"doc":"glisten/tcp","title":"accept_timeout","content":"pub fn accept_timeout(\n  socket: ListenSocket,\n  timeout: Int,\n) -&gt; Result(Socket, SocketReason)\n\nSynonyms:\nglisten/tcp.accept_timeout\nglisten/tcp accept_timeout","url":"glisten/tcp.html#accept_timeout"},{"doc":"glisten/tcp","title":"close","content":"pub fn close(socket: a) -&gt; Result(Nil, SocketReason)\n\nSynonyms:\nglisten/tcp.close\nglisten/tcp close","url":"glisten/tcp.html#close"},{"doc":"glisten/tcp","title":"controlling_process","content":"pub fn controlling_process(\n  socket: Socket,\n  pid: Pid,\n) -&gt; Result(Nil, Atom)\n\nSynonyms:\nglisten/tcp.controlling_process\nglisten/tcp controlling_process","url":"glisten/tcp.html#controlling_process"},{"doc":"glisten/tcp","title":"do_shutdown","content":"pub fn do_shutdown(\n  socket: Socket,\n  write: Atom,\n) -&gt; Result(Nil, SocketReason)\n\nSynonyms:\nglisten/tcp.do_shutdown\nglisten/tcp do_shutdown","url":"glisten/tcp.html#do_shutdown"},{"doc":"glisten/tcp","title":"handshake","content":"pub fn handshake(socket: Socket) -&gt; Result(Socket, Nil)\n\nSynonyms:\nglisten/tcp.handshake\nglisten/tcp handshake","url":"glisten/tcp.html#handshake"},{"doc":"glisten/tcp","title":"listen","content":"pub fn listen(\n  port: Int,\n  opts: List(TcpOption),\n) -&gt; Result(ListenSocket, SocketReason)\n Start listening over TCP on a port with the given options\nSynonyms:\nglisten/tcp.listen\nglisten/tcp listen","url":"glisten/tcp.html#listen"},{"doc":"glisten/tcp","title":"negotiated_protocol","content":"pub fn negotiated_protocol(socket: Socket) -&gt; a\n\nSynonyms:\nglisten/tcp.negotiated_protocol\nglisten/tcp negotiated_protocol","url":"glisten/tcp.html#negotiated_protocol"},{"doc":"glisten/tcp","title":"peername","content":"pub fn peername(\n  socket: Socket,\n) -&gt; Result(#(#(Int, Int, Int, Int), Int), Nil)\n\nSynonyms:\nglisten/tcp.peername\nglisten/tcp peername","url":"glisten/tcp.html#peername"},{"doc":"glisten/tcp","title":"receive","content":"pub fn receive(\n  socket: Socket,\n  length: Int,\n) -&gt; Result(BitArray, SocketReason)\n\nSynonyms:\nglisten/tcp.receive\nglisten/tcp receive","url":"glisten/tcp.html#receive"},{"doc":"glisten/tcp","title":"receive_timeout","content":"pub fn receive_timeout(\n  socket: Socket,\n  length: Int,\n  timeout: Int,\n) -&gt; Result(BitArray, SocketReason)\n\nSynonyms:\nglisten/tcp.receive_timeout\nglisten/tcp receive_timeout","url":"glisten/tcp.html#receive_timeout"},{"doc":"glisten/tcp","title":"send","content":"pub fn send(\n  socket: Socket,\n  packet: BytesBuilder,\n) -&gt; Result(Nil, SocketReason)\n\nSynonyms:\nglisten/tcp.send\nglisten/tcp send","url":"glisten/tcp.html#send"},{"doc":"glisten/tcp","title":"set_opts","content":"pub fn set_opts(\n  socket: Socket,\n  opts: List(TcpOption),\n) -&gt; Result(Nil, Nil)\n Update the optons for a socket (mutates the socket)\nSynonyms:\nglisten/tcp.set_opts\nglisten/tcp set_opts","url":"glisten/tcp.html#set_opts"},{"doc":"glisten/tcp","title":"shutdown","content":"pub fn shutdown(socket: Socket) -&gt; Result(Nil, SocketReason)\n\nSynonyms:\nglisten/tcp.shutdown\nglisten/tcp shutdown","url":"glisten/tcp.html#shutdown"},{"doc":"glisten/tcp","title":"socket_info","content":"pub fn socket_info(socket: Socket) -&gt; Dict(a, b)\n\nSynonyms:\nglisten/tcp.socket_info\nglisten/tcp socket_info","url":"glisten/tcp.html#socket_info"},{"doc":"glisten/tcp","title":"glisten/tcp","content":"","url":"glisten/tcp.html"},{"doc":"glisten/transport","title":"Transport","content":"pub type Transport {\n  Tcp\n  Ssl\n}\n\nTcp\n\n\nSsl\n\n\nSynonyms:\nglisten/transport.Transport\nglisten/transport Transport","url":"glisten/transport.html#Transport"},{"doc":"glisten/transport","title":"accept","content":"pub fn accept(\n  transport: Transport,\n  socket: ListenSocket,\n) -&gt; Result(Socket, SocketReason)\n\nSynonyms:\nglisten/transport.accept\nglisten/transport accept","url":"glisten/transport.html#accept"},{"doc":"glisten/transport","title":"accept_timeout","content":"pub fn accept_timeout(\n  transport: Transport,\n  socket: ListenSocket,\n  timeout: Int,\n) -&gt; Result(Socket, SocketReason)\n\nSynonyms:\nglisten/transport.accept_timeout\nglisten/transport accept_timeout","url":"glisten/transport.html#accept_timeout"},{"doc":"glisten/transport","title":"close","content":"pub fn close(\n  transport: Transport,\n  socket: Socket,\n) -&gt; Result(Nil, SocketReason)\n\nSynonyms:\nglisten/transport.close\nglisten/transport close","url":"glisten/transport.html#close"},{"doc":"glisten/transport","title":"controlling_process","content":"pub fn controlling_process(\n  transport: Transport,\n  socket: Socket,\n  pid: Pid,\n) -&gt; Result(Nil, Atom)\n\nSynonyms:\nglisten/transport.controlling_process\nglisten/transport controlling_process","url":"glisten/transport.html#controlling_process"},{"doc":"glisten/transport","title":"handshake","content":"pub fn handshake(\n  transport: Transport,\n  socket: Socket,\n) -&gt; Result(Socket, Nil)\n\nSynonyms:\nglisten/transport.handshake\nglisten/transport handshake","url":"glisten/transport.html#handshake"},{"doc":"glisten/transport","title":"listen","content":"pub fn listen(\n  transport: Transport,\n  port: Int,\n  opts: List(TcpOption),\n) -&gt; Result(ListenSocket, SocketReason)\n\nSynonyms:\nglisten/transport.listen\nglisten/transport listen","url":"glisten/transport.html#listen"},{"doc":"glisten/transport","title":"negotiated_protocol","content":"pub fn negotiated_protocol(\n  transport: Transport,\n  socket: Socket,\n) -&gt; Result(String, String)\n\nSynonyms:\nglisten/transport.negotiated_protocol\nglisten/transport negotiated_protocol","url":"glisten/transport.html#negotiated_protocol"},{"doc":"glisten/transport","title":"peername","content":"pub fn peername(\n  transport: Transport,\n  socket: Socket,\n) -&gt; Result(#(#(Int, Int, Int, Int), Int), Nil)\n\nSynonyms:\nglisten/transport.peername\nglisten/transport peername","url":"glisten/transport.html#peername"},{"doc":"glisten/transport","title":"receive","content":"pub fn receive(\n  transport: Transport,\n  socket: Socket,\n  amount: Int,\n) -&gt; Result(BitArray, SocketReason)\n\nSynonyms:\nglisten/transport.receive\nglisten/transport receive","url":"glisten/transport.html#receive"},{"doc":"glisten/transport","title":"receive_timeout","content":"pub fn receive_timeout(\n  transport: Transport,\n  socket: Socket,\n  amount: Int,\n  timeout: Int,\n) -&gt; Result(BitArray, SocketReason)\n\nSynonyms:\nglisten/transport.receive_timeout\nglisten/transport receive_timeout","url":"glisten/transport.html#receive_timeout"},{"doc":"glisten/transport","title":"send","content":"pub fn send(\n  transport: Transport,\n  socket: Socket,\n  data: BytesBuilder,\n) -&gt; Result(Nil, SocketReason)\n\nSynonyms:\nglisten/transport.send\nglisten/transport send","url":"glisten/transport.html#send"},{"doc":"glisten/transport","title":"set_opts","content":"pub fn set_opts(\n  transport: Transport,\n  socket: Socket,\n  opts: List(TcpOption),\n) -&gt; Result(Nil, Nil)\n\nSynonyms:\nglisten/transport.set_opts\nglisten/transport set_opts","url":"glisten/transport.html#set_opts"},{"doc":"glisten/transport","title":"shutdown","content":"pub fn shutdown(\n  transport: Transport,\n  socket: Socket,\n) -&gt; Result(Nil, SocketReason)\n\nSynonyms:\nglisten/transport.shutdown\nglisten/transport shutdown","url":"glisten/transport.html#shutdown"},{"doc":"glisten/transport","title":"socket_info","content":"pub fn socket_info(socket: Socket) -&gt; Dict(Atom, Dynamic)\n\nSynonyms:\nglisten/transport.socket_info\nglisten/transport socket_info","url":"glisten/transport.html#socket_info"},{"doc":"glisten/transport","title":"glisten/transport","content":"","url":"glisten/transport.html"},{"doc":"glisten","title":"ClientIp","content":"pub type ClientIp =\n  InternalClientIp\n\n\nSynonyms:\nglisten.ClientIp\nglisten ClientIp","url":"glisten.html#ClientIp"},{"doc":"glisten","title":"Connection","content":"pub type Connection(user_message) {\n  Connection(\n    client_ip: ClientIp,\n    socket: Socket,\n    transport: Transport,\n    subject: Subject(handler.Message(user_message)),\n  )\n}\n This type holds useful bits of data for the active connection.\nConnection(\n  client_ip: ClientIp,\n  socket: Socket,\n  transport: Transport,\n  subject: Subject(handler.Message(user_message)),\n)\n\nclient_ip\n&lt;p&gt;This will be optionally a tuple for the IPv4 of the other end of the\nsocket&lt;/p&gt;\n\ntransport\n&lt;p&gt;This provides a uniform interface for both TCP and SSL methods.&lt;/p&gt;\n\nSynonyms:\nglisten.Connection\nglisten Connection","url":"glisten.html#Connection"},{"doc":"glisten","title":"Handler","content":"pub opaque type Handler(user_message, data)\n\n\nSynonyms:\nglisten.Handler\nglisten Handler","url":"glisten.html#Handler"},{"doc":"glisten","title":"Loop","content":"pub type Loop(user_message, data) =\n  fn(Message(user_message), data, Connection(user_message)) -&gt;\n    actor.Next(Message(user_message), data)\n This is the shape of the function you need to provide for the `handler`\n argument to `serve(_ssl)`.\n\nSynonyms:\nglisten.Loop\nglisten Loop","url":"glisten.html#Loop"},{"doc":"glisten","title":"Message","content":"pub type Message(user_message) {\n  Packet(BitArray)\n  User(user_message)\n}\n Your provided loop function with receive these message types as the\n first argument.\nPacket(BitArray)\n These are messages received from the socket\n\nUser(user_message)\n These are any messages received from the selector returned from `on_init`\n\nSynonyms:\nglisten.Message\nglisten Message","url":"glisten.html#Message"},{"doc":"glisten","title":"Socket","content":"pub type Socket =\n  InternalSocket\n\n\nSynonyms:\nglisten.Socket\nglisten Socket","url":"glisten.html#Socket"},{"doc":"glisten","title":"SocketReason","content":"pub type SocketReason =\n  InternalSocketReason\n\n\nSynonyms:\nglisten.SocketReason\nglisten SocketReason","url":"glisten.html#SocketReason"},{"doc":"glisten","title":"StartError","content":"pub type StartError {\n  ListenerClosed\n  ListenerTimeout\n  AcceptorTimeout\n  AcceptorFailed(process.ExitReason)\n  AcceptorCrashed(Dynamic)\n  SystemError(SocketReason)\n}\n Reasons that `serve` might fail\nListenerClosed\n\n\nListenerTimeout\n\n\nAcceptorTimeout\n\n\nAcceptorFailed(process.ExitReason)\n\n\nAcceptorCrashed(Dynamic)\n\n\nSystemError(SocketReason)\n\n\nSynonyms:\nglisten.StartError\nglisten StartError","url":"glisten.html#StartError"},{"doc":"glisten","title":"handler","content":"pub fn handler(\n  on_init: fn() -&gt; #(a, Option(Selector(b))),\n  loop: fn(Message(b), a, Connection(b)) -&gt; Next(Message(b), a),\n) -&gt; Handler(b, a)\n Create a new handler for each connection.  The required arguments mirror the\n `actor.start` API from `gleam_otp`.  The default pool is 10 accceptor\n processes.\nSynonyms:\nglisten.handler\nglisten handler","url":"glisten.html#handler"},{"doc":"glisten","title":"send","content":"pub fn send(\n  conn: Connection(a),\n  msg: BytesBuilder,\n) -&gt; Result(Nil, SocketReason)\n Sends a BytesBuilder message over the socket using the active transport\nSynonyms:\nglisten.send\nglisten send","url":"glisten.html#send"},{"doc":"glisten","title":"serve","content":"pub fn serve(\n  handler: Handler(a, b),\n  port: Int,\n) -&gt; Result(Subject(Message), StartError)\n Start the TCP server with the given handler on the provided port\nSynonyms:\nglisten.serve\nglisten serve","url":"glisten.html#serve"},{"doc":"glisten","title":"serve_ssl","content":"pub fn serve_ssl(\n  handler: Handler(a, b),\n  port port: Int,\n  certfile certfile: String,\n  keyfile keyfile: String,\n) -&gt; Result(Subject(Message), StartError)\n Start the SSL server with the given handler on the provided port.  The key\n and cert files must be provided, valid, and readable by the current user.\nSynonyms:\nglisten.serve_ssl\nglisten serve_ssl","url":"glisten.html#serve_ssl"},{"doc":"glisten","title":"with_close","content":"pub fn with_close(\n  handler: Handler(a, b),\n  on_close: fn(b) -&gt; Nil,\n) -&gt; Handler(a, b)\n Adds a function to the handler to be called when the connection is closed.\nSynonyms:\nglisten.with_close\nglisten with_close","url":"glisten.html#with_close"},{"doc":"glisten","title":"with_pool_size","content":"pub fn with_pool_size(\n  handler: Handler(a, b),\n  size: Int,\n) -&gt; Handler(a, b)\n Modify the size of the acceptor pool\nSynonyms:\nglisten.with_pool_size\nglisten with_pool_size","url":"glisten.html#with_pool_size"},{"doc":"glisten","title":"glisten","content":"","url":"glisten.html"}]);